@@ -87,7 +87,9 @@ class RVTransform(abc.ABC):
         # )
         # return at.log(at.abs_(jac))
         phi_inv = self.backward(value, *inputs)
-        return at.log(at.abs(at.nlinalg.det(at.atleast_2d(jacobian(phi_inv, [value])))))
+        return at.log(
+            at.abs(at.nlinalg.det(at.atleast_2d(jacobian(phi_inv, [value])[0])))
+        )
 
 
 class DefaultTransformSentinel:
@@ -284,7 +286,7 @@ class LogOddsTransform(RVTransform):
         return at.log(sigmoid_value) + at.log1p(-sigmoid_value)
 
 
-class Simplex(RVTransform):
+class SimplexTransform(RVTransform):
     name = "simplex"
 
     def forward(self, value, *inputs):
@@ -465,5 +467,5 @@ TransformedVonMisesRV = create_default_transformed_rv_op(
 )
 TransformedDirichletRV = create_default_transformed_rv_op(
     at.random.dirichlet,
-    Simplex(),
+    SimplexTransform(),
 )
